# SRMASV Protobuf Library
------
[ ![Codeship Status for akashp1997/asv_protobuf](https://app.codeship.com/projects/c809ada0-9fbf-0136-d501-4a148af4eb21/status?branch=master)](https://app.codeship.com/projects/306478)
This repository contains the SRMASV protobuf library.
------
## To install just run the following:
`python setup.py install`

The following module contains the following messages implemented in Google Protobuf:

#### asvprotobuf.std
-----
- [x] Header
- [x] Orientation
- [x] Vector

#### asvprotobuf.sensor
-----
- [x] Imu
- [x] GPSFix
- [x] Image
- [x] LaserScan
- [x] Raw

#### asvprotobuf.diagnostics
-----
- TODO
